﻿/*
 *         Progetto: Semplice animazione in WPF
 * 
 *           Autore: Roberto Fuligni
 *  Ultima modifica: 25/11/2018
 *  
 */

using System.Threading;
using System.Threading.Tasks;
using System.Windows;

namespace ThreadImmagine
{
    /// <summary>
    /// Logica di interazione per MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void EseguiDecollo()
        {
            const double DX = 10;
            const double DY = -5;

            // Fase 1 - Si disabilita il bottone "Decolla"
            //          (non si deve iniziare un nuovo decollo
            //           prima di aver completato quello corrente)

            Dispatcher.Invoke(() =>
            {
                btnDecolla.IsEnabled = false;
            });

            // Fase 2 - Simulazione della fase di decollo
            //          Si sposta ripetutamente l'immagine modificandone i margini.
            //          La velocità dell'animazione è regolata introducendo 
            //          opportuni ritardi (sleep).

            for(int i = 0; i < 76; i++)
            {
                Thread.Sleep(100);
                // Aggiornamento dell'interfaccia grafica
                Dispatcher.Invoke(() =>
                {
                    Thickness margini = imgAereo.Margin;
                    margini.Left += DX;
                    margini.Top += DY;
                    imgAereo.Margin = margini;
                });
                
            }

            // Fase 3 - Conclusa l'animazione, si riporta l'areo nella
            //          posizione di partenza e si riabilita il bottone.

            Dispatcher.Invoke(() =>
            {
                imgAereo.Margin = new Thickness(10, 320, 0, 0);     // Left: 10; Top: 320; Bottom e Right: 0
                btnDecolla.IsEnabled = true;
            });
        }

        private void btnDecolla_Click(object sender, RoutedEventArgs e)
        {
            // Cliccando sul bottone, si esegue l'animazione con un nuovo task
            Task.Factory.StartNew(EseguiDecollo);
        }
    }
}
